@@ -202,6 +202,10 @@ void GSM_StateMachine::ReadCfg(GSM_GPlusConfig *CFG)
 	strcpy(CFG->SyncTime,"no");
 	value = File.GetValue(x,StringToUnicodeReturn("synchronizetime"));
 	if (value != NULL) sprintf(CFG->SyncTime,"%s",UnicodeToStringReturn(value));
+
+	strcpy(CFG->GetOnlineInfo,"no");
+	value = File.GetValue(x,StringToUnicodeReturn("usephonedb"));
+	if (value != NULL) sprintf(CFG->GetOnlineInfo,"%s",UnicodeToStringReturn(value));
 }
 
 /**
@@ -238,6 +242,9 @@ void GSM_StateMachine::SaveCfg(GSM_GPlusConfig *CFG)
 	StringToUnicode("synchronizetime",x2);
 	File.SetValue(x,x2,StringToUnicodeReturn(CFG->SyncTime));
 
+	StringToUnicode("usephonedb",x2);
+	File.SetValue(x,x2,StringToUnicodeReturn(CFG->GetOnlineInfo));
+
 	if (read) {
 		File.SaveToDisk(UnicodeToStringReturn(File.Info.ID.data()));
 	} else {
