@@ -415,7 +415,7 @@ BOOLEAN Gen_File::SaveToDisk(char *FileName)
 	return TRUE;
 }
 
-BOOLEAN Gen_File::ReadFromWWW(char *server, char *filename)
+BOOLEAN Gen_File::ReadFromHTTPGet(char *server, char *filename)
 {
 	int			s, len;
 	struct sockaddr_in 	address;
@@ -446,13 +446,6 @@ BOOLEAN Gen_File::ReadFromWWW(char *server, char *filename)
 		return FALSE;
 	}
 
-//	sprintf(buff,"POST %s HTTP/1.1\n",filename);
-//	sprintf(buff+strlen(buff),"User-Agent: Mozilla/4.0\n");
-//	sprintf(buff+strlen(buff),"Host: europe.nokia.com\n");
-//	sprintf(buff+strlen(buff),"Content-Length: 11\n");
-//	sprintf(buff+strlen(buff),"Content-Type: application/x-www-form-urlencoded\n\n");
-//	sprintf(buff+strlen(buff),"id=45f1f1c1");
-
 	sprintf(buff,"GET http://%s/%s HTTP/1.0\n\n",server,filename);
 	if (send(s,buff,strlen(buff),0)<0) return FALSE;
 
@@ -472,7 +465,73 @@ BOOLEAN Gen_File::ReadFromWWW(char *server, char *filename)
 #endif
 
 	if (Buffer.size()==0) return TRUE;
-//	printf("%s\n",Buffer.data());
+	if (strstr((const char *)Buffer.data(),"HTTP/1.0 200 OK")==NULL &&
+	    strstr((const char *)Buffer.data(),"HTTP/1.1 200 OK")==NULL) {
+		Buffer.clear();
+		return FALSE;
+	}
+
+ 	Info.Size = Buffer.size();
+
+	return TRUE;
+}
+
+BOOLEAN Gen_File::ReadFromHTTPPost(char *server, char *filename, char *content)
+{
+	int			s, len;
+	struct sockaddr_in 	address;
+	struct hostent 		*address2;
+	char 			buff[20000];
+#ifdef WIN32
+	WSADATA			wsaData;
+
+	if (WSAStartup(MAKEWORD(1, 1), &wsaData) != 0) return FALSE;
+#endif
+
+	s = socket(AF_INET,SOCK_STREAM,0);
+#ifdef WIN32
+	if (s==INVALID_SOCKET) return FALSE;
+#else
+	if (s==-1) return FALSE;
+#endif
+
+	address2 = gethostbyname(server);
+	if (address2 == NULL) return FALSE;
+
+	memset((char *) &address, 0, sizeof(address));
+	address.sin_family 	= AF_INET;
+	address.sin_port 	= htons(80);
+	address.sin_addr.s_addr = *(u_long *) *(address2->h_addr_list);
+
+	if (connect(s,(struct sockaddr *)&address,sizeof(address))<0) {
+		return FALSE;
+	}
+
+	sprintf(buff,"POST http://%s%s HTTP/1.0\n",server,filename);
+	sprintf(buff+strlen(buff),"User-Agent: Mozilla/4.0\n");
+	sprintf(buff+strlen(buff),"Host: %s\n",server);
+	sprintf(buff+strlen(buff),"Content-Length: %i\n",strlen(content));
+	sprintf(buff+strlen(buff),"Content-Type: application/x-www-form-urlencoded\n\n");
+	sprintf(buff+strlen(buff),"%s",content);
+
+	if (send(s,buff,strlen(buff),0)<0) return FALSE;
+
+	Buffer.clear();
+
+#ifdef WIN32
+	while ((len=recv(s,buff,200,0))>0) {
+#else
+	while ((len=read(s,buff,200))>0) {
+#endif
+		Buffer.append((const unsigned char *)buff,len);
+	}
+#ifdef WIN32
+	closesocket(s);
+#else
+	close(s);
+#endif
+
+	if (Buffer.size()==0) return TRUE;
 	if (strstr((const char *)Buffer.data(),"HTTP/1.0 200 OK")==NULL &&
 	    strstr((const char *)Buffer.data(),"HTTP/1.1 200 OK")==NULL) {
 		Buffer.clear();
