@@ -52,8 +52,10 @@ const int ID_AddNote             = 33;
 const int ID_DelNote             = 34;
 const int ID_GetToDo             = 35;
 const int ID_GetProductCode      = 36;
+const int ID_AddToDo             = 37;
+const int ID_SetDateTime	 = 38;
 
-const int ID_Start               = 36; //set it to last value above
+const int ID_Start               = 38; //set it to last value above
 
 class GSM_Device;
 class GSM_AllDevices;
@@ -117,6 +119,7 @@ public:
 	virtual GSM_Error	GetProductCode(unsigned char *ProductCode);
         //date time
         virtual GSM_Error       GetDateTime(GSM_DateTime *DT);
+        virtual GSM_Error       SetDateTime(GSM_DateTime *DT);
         //phonebook memories
         virtual GSM_Error       GetPBKStatus(GSM_PBKStatus *Status);
         virtual GSM_Error       GetPBK(GSM_PBKEntry *Entry);
