@@ -168,7 +168,7 @@ GSM_Error GSM_Phone_N7110::SetPBK(GSM_PBKEntry *Entry)
 	Buff[12] = Entry->Location / 256;
 	Buff[13] = Entry->Location % 256;
 
-	error = DCT34->EncodeEntryToPBK(&Buffer, Entry, &Number);
+	error = DCT34->EncodeEntryToPBK(&Buffer, Entry, &Number, NULL);
 	if (error.Code != GSM_ERR_NONE) return error;
 
 	Buffer2.append((const unsigned char*)Buff,sizeof(Buff));
