@@ -37,20 +37,22 @@ public:
         /*2*/   Info.push_back(GSM_Phone_Info("5140" , "NPL-5"  ,  "Nokia 5140"  ,"fbus|irdaphonet", ""));
         /*2*/   Info.push_back(GSM_Phone_Info("5140b", "NPL-4"  ,  "Nokia 5140"  ,"fbus|irdaphonet", ""));
         /*2*/   Info.push_back(GSM_Phone_Info("5140i", "RM-104" ,  "Nokia 5140i" ,"fbus|irdaphonet", ""));
-//5200 - RM-174
+        /*3FP2*/Info.push_back(GSM_Phone_Info("5200",  "RM-174" ,  "Nokia 5200"  ,"fbus|irdaphonet|phonetblue|bluephonet|bluerfphonet|dku2phonet|dku2", "-s40_30-"));
         /*2*/   Info.push_back(GSM_Phone_Info("6020" , "RM-30"  ,  "Nokia 6020"  ,"fbus|irdaphonet", ""));
         /*2*/   Info.push_back(GSM_Phone_Info("6020b", "RM-31"  ,  "Nokia 6020"  ,"fbus|irdaphonet", ""));
-        /*1*/   Info.push_back(GSM_Phone_Info("6100" , "NPL-2"  ,  "Nokia 6100"  ,"fbus|irdaphonet|bluephonet|bluerfphonet|dku2phonet|dku2", ""));
-        /*3*/   Info.push_back(GSM_Phone_Info("6111" , "RM-82"  ,  "Nokia 6111"  ,"fbus|irdaphonet|bluephonet|bluerfphonet|dku2phonet|dku2", "-s40_30--todo6610-"));
+        /*1*/   Info.push_back(GSM_Phone_Info("6100" , "NPL-2"  ,  "Nokia 6100"  ,"fbus|irdaphonet|phonetblue|bluephonet|bluerfphonet|dku2phonet|dku2", ""));
+        /*3*/   Info.push_back(GSM_Phone_Info("6111" , "RM-82"  ,  "Nokia 6111"  ,"fbus|irdaphonet|phonetblue|bluephonet|bluerfphonet|dku2phonet|dku2", "-s40_30--todo6610-"));
         /*1*/   Info.push_back(GSM_Phone_Info("6170" , "RM-47"  ,  "Nokia 6170"  ,"fbus|irdaphonet|dku2phonet|dku2", ""));
         /*1*/   Info.push_back(GSM_Phone_Info("6220" , "RH-20"  ,  "Nokia 6220"  ,"fbus|irdaphonet|dku5fbus|dku5", "-file1only-"));
-        /*2*/   Info.push_back(GSM_Phone_Info("6230" , "RH-12"  ,  "Nokia 6230"  ,"fbus|irdaphonet|bluephonet|bluerfphonet|dku2phonet|dku2", "-file1-"));
-        /*2*/   Info.push_back(GSM_Phone_Info("6230b", "RH-28"  ,  "Nokia 6230"  ,"fbus|irdaphonet|bluephonet|bluerfphonet|dku2phonet|dku2", "-file1-"));
-        /*2*/   Info.push_back(GSM_Phone_Info("6230i", "RM-72"  ,  "Nokia 6230i" ,"fbus|irdaphonet|bluephonet|bluerfphonet|dku2phonet|dku2", "-file1-"));
-        /*3*/   Info.push_back(GSM_Phone_Info("6233",  "RM-145" ,  "Nokia 6233"  ,"fbus|irdaphonet|bluephonet|bluerfphonet|dku2phonet|dku2", "-s40_30-"));
-        /*3*/   Info.push_back(GSM_Phone_Info("6234",  "RM-123" ,  "Nokia 6234"  ,"fbus|irdaphonet|bluephonet|bluerfphonet|dku2phonet|dku2", "-s40_30-"));
-                Info.push_back(GSM_Phone_Info("6310",  "NPE-4"  ,  "Nokia 6310"  ,"fbus|irdaphonet|bluephonet|bluerfphonet|dlr3fbus|dlr3", "-cal65--nofile-"));
-                Info.push_back(GSM_Phone_Info("6310i", "NPL-1"  ,  "Nokia 6310i" ,"fbus|irdaphonet|bluephonet|bluerfphonet|dlr3fbus|dlr3", "-cal65--file1only-"));
+        /*2*/   Info.push_back(GSM_Phone_Info("6230" , "RH-12"  ,  "Nokia 6230"  ,"fbus|irdaphonet|phonetblue|bluephonet|bluerfphonet|dku2phonet|dku2", "-file1--todo6610-"));
+        /*2*/   Info.push_back(GSM_Phone_Info("6230b", "RH-28"  ,  "Nokia 6230"  ,"fbus|irdaphonet|phonetblue|bluephonet|bluerfphonet|dku2phonet|dku2", "-file1--todo6610-"));
+        /*2*/   Info.push_back(GSM_Phone_Info("6230i", "RM-72"  ,  "Nokia 6230i" ,"fbus|irdaphonet|phonetblue|bluephonet|bluerfphonet|dku2phonet|dku2", "-file1--todo6610-"));
+        /*3*/   Info.push_back(GSM_Phone_Info("6233",  "RM-145" ,  "Nokia 6233"  ,"fbus|irdaphonet|phonetblue|bluephonet|bluerfphonet|dku2phonet|dku2", "-s40_30-"));
+        /*3*/   Info.push_back(GSM_Phone_Info("6234",  "RM-123" ,  "Nokia 6234"  ,"fbus|irdaphonet|phonetblue|bluephonet|bluerfphonet|dku2phonet|dku2", "-s40_30-"));
+        /*3*/   Info.push_back(GSM_Phone_Info("6234",  "RM-123" ,  "Nokia 6234"  ,"fbus|irdaphonet|phonetblue|bluephonet|bluerfphonet|dku2phonet|dku2", "-s40_30-"));
+        /*3FP2*/Info.push_back(GSM_Phone_Info("6300",  "RM-217" ,  "Nokia 6300"  ,"fbus|irdaphonet|phonetblue|bluephonet|bluerfphonet|dku2phonet|dku2", "-s40_30-"));
+        /*0*/   Info.push_back(GSM_Phone_Info("6310",  "NPE-4"  ,  "Nokia 6310"  ,"fbus|irdaphonet|phonetblue|bluephonet|bluerfphonet|dlr3fbus|dlr3", "-cal65--nofile-"));
+                Info.push_back(GSM_Phone_Info("6310i", "NPL-1"  ,  "Nokia 6310i" ,"fbus|irdaphonet|phonetblue|bluephonet|bluerfphonet|dlr3fbus|dlr3", "-cal65--file1only-"));
                 Info.push_back(GSM_Phone_Info("6510" , "NPM-9"  ,  "Nokia 6510"  ,"fbus|irdaphonet", "-cal65-"));
                 Info.push_back(GSM_Phone_Info("6610" , "NHL-4U" ,  "Nokia 6610"  ,"fbus|irdaphonet", ""));
                 Info.push_back(GSM_Phone_Info("6610i", "RM-37"  ,  "Nokia 6610i" ,"fbus|irdaphonet", ""));
@@ -96,6 +98,7 @@ public:
 	GSM_Error 	 GetProductCode		(unsigned char *ProductCode);
         //date time
         GSM_Error        GetDateTime            (GSM_DateTime *DT);
+	GSM_Error 	 SetDateTime		(GSM_DateTime *DT);
         //phonebook memories
         GSM_Error        GetPBKStatus           (GSM_PBKStatus *Status);
         GSM_Error        GetPBK                 (GSM_PBKEntry *Entry);
@@ -162,6 +165,8 @@ private:
         GSM_FileFolderInfoList          JavaFInfo;
         GSM_FileFolderInfoListSubEntry  *JavaFInfoSubEntry;
 	
+	GSM_Error 	 ReplySetDateTime	(GSM_Protocol_Message *msg, DebugInfo **Debug, unsigned char *s);
+
 	//calendar,note,todo
 	void 		 FindCalendarDateDifference(GSM_DateTime *DT,long diff);
 	GSM_Error 	 GetNextCalendar3NoteToDo2(void *Entry, BOOLEAN start, int *Current, int *Max, int *Location, unsigned char Type, int request);
@@ -169,7 +174,7 @@ private:
 	GSM_Error 	 GetCalendar3NoteToDo2Info(unsigned char type);
         GSM_Error        AddCalendar3           (GSM_CalendarEntry *Entry);
 	GSM_Error 	 AddToDo2		(GSM_ToDoEntry *Entry);
-        GSM_Error        GetFirstCalendarPos3   (int *Location);
+        GSM_Error        GetFirstCalendarPos3   (int *Location,unsigned char type);
 	GSM_Error 	 FindCalendarNoteType3	(GSM_CalendarEntry *Entry, int *NoteID);
         //sms
         GSM_Error        GetSMSFolderStatus1    (GSM_SMS_Loc *SMSLocations);
@@ -221,6 +226,8 @@ private:
         GSM_Error        ReplyGetCalendarNoteToDoInfo3(GSM_Protocol_Message *msg, DebugInfo **Debug, unsigned char *S);
         GSM_Error        ReplyGetDateTime       (GSM_Protocol_Message *msg, DebugInfo **Debug, unsigned char *S);
         GSM_Error        ReplyAddCalendar3      (GSM_Protocol_Message *msg, DebugInfo **Debug, unsigned char *S);
+	GSM_Error 	 ReplyAddToDo2		(GSM_Protocol_Message *msg, DebugInfo **Debug, unsigned char *S);
+	GSM_Error 	 ReplyAddNote		(GSM_Protocol_Message *msg, DebugInfo **Debug, unsigned char *S);
         GSM_Error        ReplyGetFirstCalPos3   (GSM_Protocol_Message *msg, DebugInfo **Debug, unsigned char *S);
         //sms
         GSM_Error        ReplyGetSMSStatus1     (GSM_Protocol_Message *msg, DebugInfo **Debug, unsigned char *S);
