@@ -443,7 +443,7 @@ GSM_Error GSM_Phone_NDCT34::DecodePBKToEntry(const unsigned char *Buffer, GSM_PB
 	int		     	i, j, Pos = 1,Num;
 	GSM_PBK_SubEntryType    Type;
 	GSM_PBKSubEntry 	*SubEntry,*PrevSubEntry=NULL;
-	BOOLEAN			Found;
+	BOOLEAN			Found,LastFirst=FALSE;
 
 	(*Debug)->Deb("  %i blocks\n",Buffer[0]);
 	for (i=0;i<Buffer[0];i++) {
@@ -505,16 +505,18 @@ GSM_Error GSM_Phone_NDCT34::DecodePBKToEntry(const unsigned char *Buffer, GSM_PB
 			}
 		case NPBK_NAME: // no break;
 			if (Type == PBK_Not_Assigned) {
-				Type = PBK_Text_Name;
 				(*Debug)->Deb("      Name");
+				break;
 			}
 		case NPBK_NAME_FIRST: // no break;
 			if (Type == PBK_Not_Assigned) {
+				LastFirst = TRUE;
 				Type = PBK_Text_Name_First;
 				(*Debug)->Deb("      First name");
 			}
 		case NPBK_NAME_LAST: // no break;
 			if (Type == PBK_Not_Assigned) {
+				LastFirst = TRUE;
 				Type = PBK_Text_Name_Last;
 				(*Debug)->Deb("      Last name");
 			}
@@ -643,6 +645,20 @@ GSM_Error GSM_Phone_NDCT34::DecodePBKToEntry(const unsigned char *Buffer, GSM_PB
 		}
 		Pos+=Buffer[Pos+2]*256+Buffer[Pos+3];
 	}
+	if (!LastFirst) {
+		Pos = 1;
+		for (i=0;i<Buffer[0];i++) {
+			(*Debug)->Deb("    Block length %i, type %02X\n",Buffer[Pos+2]*256+Buffer[Pos+3],Buffer[Pos]);
+			Type = PBK_Not_Assigned;
+
+			if (Buffer[Pos]==NPBK_NAME) {
+				(*Debug)->Deb("      Name");
+				(*Debug)->Deb(" \"%s\"\n",UnicodeToStringReturn(NokiaGetUnicodeString(Buffer+Pos+6)));
+				Entry->AddText(PBK_Text_Name_Last, NokiaGetUnicodeString(Buffer+Pos+6));
+			}
+			Pos+=Buffer[Pos+2]*256+Buffer[Pos+3];
+		}
+	}
 	SubEntry = NULL;
 	while (Entry->GetNext(&SubEntry) == TRUE) {
 		if (SubEntry->GetType()!=PBK_DateTime_Call_Length) continue;
