@@ -3,13 +3,65 @@
 #include "../../../cfg/config.h" //msvc2005
 #include "../../misc/files.h"
 #include "../../misc/coding/coding.h"
+#include "../../misc/coding/md5.h"
 #include "../gsmpbk.h"
 #include "gsmback.h"
 
+GSM_Error GSM_Backup::FindTextFileChecksum(INI_File *File, char *checksum)
+{
+	INI_File_Section 	*Section;
+	INI_File_Entry 		*Entry;
+	wchart			Buff,Buff2,Buff3;
+	unsignedstring		Buff4;
+	wchar_t			x[200];
+	//variables taken from md5main.c
+	md5_state_t 		state;
+	md5_byte_t 		digest[16];
+	char 			hex_output[16*2 + 1];
+	int 			di;
+
+	StringToUnicode("Checksum",x);
+
+	Section = NULL;
+	while (File->GetNextSection(&Section)) {
+		if (UnicodeCaseCmp(x,Section->Name.data(),-1)) continue;
+
+		Buff.append(Section->Name.data(),Section->Name.size());
+		Buff3.clear();
+		Entry = NULL;
+		while (Section->GetNextEntry(&Entry)) {
+			//we add next entry on start because it's done this way in Gammu
+			Buff2.clear();
+			Buff2.append(Entry->Name.data(),Entry->Name.size());
+			Buff2.append(Entry->Value.data(),Entry->Value.size());
+			Buff2.append(Buff3.data(),Buff3.size());
+			Buff3.clear();
+			Buff3.append(Buff2.data(),Buff2.size());
+		}
+		Buff.append(Buff3.data(),Buff3.size());
+	}
+
+	for (di=0;di<Buff.size();di++) {
+		Buff4.push_back(Buff.data()[di]/256);
+		Buff4.push_back(Buff.data()[di]%256);
+	}
+
+	//4 lines taken from md5main.c
+	md5_init(&state);
+	md5_append(&state, (const md5_byte_t *)Buff4.data(), Buff4.size());
+	md5_finish(&state, digest);
+	for (di = 0; di < 16; ++di) sprintf(hex_output + di * 2, "%02x", digest[di]);
+
+	sprintf(checksum,"%s",hex_output);
+	for (di = 0; di < strlen(checksum); di++) checksum[di] = toupper(checksum[di]);
+
+	return GSM_Return_Error(GSM_ERR_NONE);
+}
+
 void GSM_Backup::SaveTextFilePart(wchar_t *Text, FILE *file, BOOLEAN LineEnd)
 {
-	int i = 0;
-	unsignedstring Buffer;
+	int 		i = 0;
+	unsignedstring 	Buffer;
 
 	while(1) {
 		if (Text[i] == 0x00) break;
@@ -111,13 +163,12 @@ GSM_Error GSM_Backup::SaveCalendarToTextFile(FILE *file)
 
 	Num = 1;
 	CalEntry = NULL;
-	while (GetNext_Cal(&CalEntry)) {
-		
+	while (GetNext_Cal(&CalEntry)) {		
 		SaveTextFilePart(StringToUnicodeReturn(""), file, TRUE);
 		sprintf(buff,"[Calendar%03i]",Num);
 		SaveTextFilePart(StringToUnicodeReturn(buff), file, TRUE);
-//		sprintf(buff,"Location = %03i",PBKEntry->GetEntry()->Location);
-//		SaveTextFilePart(StringToUnicodeReturn(buff), file, TRUE);
+		sprintf(buff,"Location = %03i",CalEntry->GetEntry()->Location);
+		SaveTextFilePart(StringToUnicodeReturn(buff), file, TRUE);
 		Num++;
 
 		switch (CalEntry->GetEntry()->Type) {
@@ -285,6 +336,7 @@ GSM_Error GSM_Backup::SaveToDoToTextFile(FILE *file)
 
 GSM_Error GSM_Backup::SaveToTextFile(char *FileName)
 {
+	INI_File		File;
 	FILE			*file;
 	char			buff[100];
 	unsigned char 		buff3[100];
@@ -305,7 +357,7 @@ GSM_Error GSM_Backup::SaveToTextFile(char *FileName)
 	SaveTextFilePart(StringToUnicodeReturn("[Backup]"), file, TRUE);
 	SaveTextFilePart(StringToUnicodeReturn("Format=1.05"), file, TRUE);
 
-	sprintf(buff,"IMEI = \"%s\"",IMEI);
+	sprintf(buff,"IMEI = \"%s\"",DeviceIMEI);
 	SaveTextFilePart(StringToUnicodeReturn(buff), file, TRUE);
 
 	sprintf(buff,"Creator = \"Gammu+ %s",VERSION);
@@ -319,7 +371,7 @@ GSM_Error GSM_Backup::SaveToTextFile(char *FileName)
 	SaveVCalendarDateTime(&DT,buff);
 	SaveTextFilePart(StringToUnicodeReturn(buff), file, TRUE);
 
-	sprintf(buff,"Phone = \"%s\"",Model);
+	sprintf(buff,"Phone = \"%s\"",DeviceModel);
 	SaveTextFilePart(StringToUnicodeReturn(buff), file, TRUE);
 
 	SavePbkToTextFile(file);
@@ -329,6 +381,15 @@ GSM_Error GSM_Backup::SaveToTextFile(char *FileName)
 
 	fclose(file);
 
+	File.ReadFile(FileName);
+	FindTextFileChecksum(&File, (char *)buff3);
+	file = fopen(FileName,"ab");
+	SaveTextFilePart(StringToUnicodeReturn(""), file, TRUE);
+	SaveTextFilePart(StringToUnicodeReturn("[Checksum]"), file, TRUE);
+	sprintf(buff,"MD5=%s",buff3);
+	SaveTextFilePart(StringToUnicodeReturn(buff), file, TRUE);
+	fclose(file);
+
 	return GSM_Return_Error(GSM_ERR_UNKNOWN);
 }
 
@@ -358,7 +419,7 @@ GSM_Error GSM_Backup::ReadPbkFromTextFile(INI_File *File)
 		PBKEntry 		= new GSM_PBKEntry;
 		PBKEntry->Location 	= atoi(UnicodeToStringReturn(value));
 		PBKEntry->Memory	= MEM_PHONE;
-		for (i=0;i<20;i++) {
+		for (i=0;i<50;i++) {
 			sprintf(x2,"Entry%02iType",i);
 			value = File->GetValue((wchar_t *)Section->Name.data(),StringToUnicodeReturn(x2));
 			if (value == NULL) continue;
@@ -406,7 +467,7 @@ GSM_Error GSM_Backup::ReadPbkFromTextFile(INI_File *File)
 			}
 		}
 		if (!Found) {
-			for (i=0;i<20;i++) {
+			for (i=0;i<50;i++) {
 				sprintf(x2,"Entry%02iType",i);
 				value = File->GetValue((wchar_t *)Section->Name.data(),StringToUnicodeReturn(x2));
 				if (value == NULL) continue;
@@ -655,25 +716,35 @@ GSM_Error GSM_Backup::ReadFromTextFile(char *FileName)
 
 	value = File.GetValue(x,StringToUnicodeReturn("IMEI"));
 	if (value != NULL) {
-		sprintf(IMEI,"%s",UnicodeToStringReturn(value+1));
-		IMEI[strlen(IMEI)-1] = 0;
+		sprintf(DeviceIMEI,"%s",UnicodeToStringReturn(value+1));
+		DeviceIMEI[strlen(DeviceIMEI)-1] = 0;
 	}
 
 	value = File.GetValue(x,StringToUnicodeReturn("Creator"));
 	if (value != NULL) {
-		sprintf(Creator,"%s",UnicodeToStringReturn(value+1));
-		Creator[strlen(Creator)-1] = 0;
+		sprintf(FileCreator,"%s",UnicodeToStringReturn(value+1));
+		FileCreator[strlen(FileCreator)-1] = 0;
 	}
 
 	value = File.GetValue(x,StringToUnicodeReturn("Phone"));
 	if (value != NULL) {
-		sprintf(Model,"%s",UnicodeToStringReturn(value+1));
-		Model[strlen(Model)-1] = 0;
+		sprintf(DeviceModel,"%s",UnicodeToStringReturn(value+1));
+		DeviceModel[strlen(DeviceModel)-1] = 0;
 	}
 
 	value = File.GetValue(x,StringToUnicodeReturn("DateTime"));
-	if (value != NULL && ReadVCalendarDateTime(UnicodeToStringReturn(value), &DateTime)==TRUE) {
-		DateTimeAvailable=TRUE;
+	if (value != NULL && ReadVCalendarDateTime(UnicodeToStringReturn(value), &FileDateTime)==TRUE) {
+		FileDateTimeAvailable=TRUE;
+	}
+
+	if ((File.Buffer.data()[0] == 0xFE && File.Buffer.data()[1] == 0xFF) ||
+	    (File.Buffer.data()[0] == 0xFF && File.Buffer.data()[1] == 0xFE)) {
+		StringToUnicode("Checksum",x);
+		value = File.GetValue(x,StringToUnicodeReturn("MD5"));
+		if (value != NULL) {
+			sprintf(FileMD5Original,"%s",UnicodeToStringReturn(value));
+			FindTextFileChecksum(&File, (char *)FileMD5Calculated);
+		}
 	}
 
 	ReadPbkFromTextFile(&File);
