@@ -512,7 +512,7 @@ GSM_Error CheckRSS(unsignedstring *StableStr, unsignedstring *TestStr)
 	StableStr->clear();
 	TestStr->clear();
 
-	if (!File.ReadFromWWW("www.mwiacek.com","gsm/soft/gplus.rss")) return GSM_Return_Error(GSM_ERR_UNKNOWN);
+	if (!File.ReadFromHTTPGet("www.mwiacek.com","gsm/soft/gplus.rss")) return GSM_Return_Error(GSM_ERR_UNKNOWN);
 	
 	while (pos < File.Buffer.size()) {
 		if (File.Buffer.data()[pos] != 10) {
