@@ -50,7 +50,8 @@ void SendSMS(GSM_StateMachine *s, GSM_GPlusConfig *CFG, int argc, char *argv[])
 
 	SMS.SetType(SMS_Submit);
 	SMS.SetCoding(SMS_Coding_Default_No_Compression);
-	SMS.SetDecodedText(StringToUnicodeReturn(argv[1]));
+	error = SMS.SetDecodedText(StringToUnicodeReturn(argv[1]));
+	PrintError(error);
 	SMS.PhoneNumbers.Add(StringToUnicodeReturn(argv[0]));
 	SMS.SetSMSCNumber(SMSC.GetSMSCNumber());
 
