@@ -51,6 +51,17 @@ class AboutDlg : public wxDialog
 		//Do not add custom control declarations
 		//wxDev-C++ will remove them. Add custom code after the block.
 		////GUI Control Declaration Start
+		wxHyperlinkCtrl *WxHyperLinkCtrl4;
+		wxStaticText *WxStaticText16;
+		wxStaticText *WxStaticText15;
+		wxStaticText *WxStaticText14;
+		wxStaticText *WxStaticText7;
+		wxStaticBox *WxStaticBox4;
+		wxStaticText *WxStaticText13;
+		wxStaticText *WxStaticText10;
+		wxHyperlinkCtrl *WxHyperLinkCtrl3;
+		wxStaticText *WxStaticText5;
+		wxStaticBox *WxStaticBox3;
 		wxStaticLine *WxStaticLine2;
 		wxStaticText *WxStaticText12;
 		wxStaticText *WxStaticText11;
@@ -77,6 +88,17 @@ class AboutDlg : public wxDialog
 		enum
 		{
 			////GUI Enum Control ID Start
+			ID_WXHYPERLINKCTRL4 = 1037,
+			ID_WXSTATICTEXT16 = 1036,
+			ID_WXSTATICTEXT15 = 1035,
+			ID_WXSTATICTEXT14 = 1034,
+			ID_WXSTATICTEXT7 = 1033,
+			ID_WXSTATICBOX4 = 1032,
+			ID_WXSTATICTEXT13 = 1031,
+			ID_WXSTATICTEXT10 = 1030,
+			ID_WXHYPERLINKCTRL3 = 1028,
+			ID_WXSTATICTEXT5 = 1027,
+			ID_WXSTATICBOX3 = 1026,
 			ID_WXSTATICLINE2 = 1025,
 			ID_WXSTATICTEXT12 = 1024,
 			ID_WXSTATICTEXT11 = 1023,
