@@ -27,6 +27,7 @@
 //Header Include Start and Header Include End.
 //wxDev-C++ designer will remove them. Add custom headers after the block.
 ////Header Include Start
+#include <wx/listctrl.h>
 #include <wx/stattext.h>
 #include <wx/combobox.h>
 #include <wx/button.h>
@@ -61,6 +62,11 @@ class BackupDlg : public wxDialog
                 //GUI Control Declaration Start and GUI Control Declaration End.
 		//wxDev-C++ will remove them. Add custom code after the block.
 		////GUI Control Declaration Start
+		wxStaticText *WxStaticText3;
+		wxListCtrl *WxListCtrl1;
+		wxStaticText *WxStaticText2;
+		wxCheckBox *WxCheckBox7;
+		wxCheckBox *WxCheckBox6;
 		wxButton *WxButton4;
 		wxButton *WxButton3;
 		wxStaticText *WxStaticText1;
@@ -73,6 +79,7 @@ class BackupDlg : public wxDialog
 		wxButton *WxButton1;
 		wxCheckBox *WxCheckBox1;
 		wxStaticBox *WxStaticBox1;
+		wxStaticBox *WxStaticBox2;
 		////GUI Control Declaration End
 		
 	private:
@@ -83,6 +90,11 @@ class BackupDlg : public wxDialog
 		enum
 		{
 			////GUI Enum Control ID Start
+			ID_WXSTATICTEXT3 = 1029,
+			ID_WXLISTCTRL1 = 1028,
+			ID_WXSTATICTEXT2 = 1017,
+			ID_WXCHECKBOX7 = 1016,
+			ID_WXCHECKBOX6 = 1015,
 			ID_WXBUTTON4 = 1014,
 			ID_WXBUTTON3 = 1013,
 			ID_WXSTATICTEXT1 = 1012,
@@ -95,12 +107,14 @@ class BackupDlg : public wxDialog
 			ID_WXBUTTON1 = 1003,
 			ID_WXCHECKBOX1 = 1002,
 			ID_WXSTATICBOX1 = 1001,
+			ID_WXSTATICBOX2 = 1021,
 			////GUI Enum Control ID End
 			ID_DUMMY_VALUE_ //don't remove this value unless you have other enum values
 		};
 
     public:
-        GSM_Backup_FileFormatFunctions *Func;        	
+        GSM_Backup_FileFormatFunctions *Func;
+		void WxCheckBox7Click(wxCommandEvent& event);
 	private:
         
 		void OnClose(wxCloseEvent& event);
