@@ -52,34 +52,35 @@ void CfgDlg::CreateGUIControls()
 
 	SetTitle(wxT("Configuration for phone connection"));
 	SetIcon(wxNullIcon);
-	SetSize(8,8,409,207);
+	SetSize(8,8,446,226);
 	Center();
 	
 
-	WxCheckBox2 = new wxCheckBox(this, ID_WXCHECKBOX2, wxT("log communication for debug"), wxPoint(14,122), wxSize(240,18), 0, wxDefaultValidator, wxT("WxCheckBox2"));
+	WxCheckBox3 = new wxCheckBox(this, ID_WXCHECKBOX3, wxT("check online info on startup (send codename and product code)"), wxPoint(14,119), wxSize(357,18), 0, wxDefaultValidator, wxT("WxCheckBox3"));
+
+	WxCheckBox2 = new wxCheckBox(this, ID_WXCHECKBOX2, wxT("log communication for debug"), wxPoint(14,143), wxSize(240,18), 0, wxDefaultValidator, wxT("WxCheckBox2"));
 
 	wxArrayString arrayStringFor_WxComboBox1;
-	WxComboBox1 = new wxComboBox(this, ID_WXCOMBOBOX1, wxT("WxComboBox1"), wxPoint(93,22), wxSize(298,21), arrayStringFor_WxComboBox1, wxCB_DROPDOWN | wxCB_READONLY | wxCB_SORT, wxDefaultValidator, wxT("WxComboBox1"));
+	WxComboBox1 = new wxComboBox(this, ID_WXCOMBOBOX1, wxT("WxComboBox1"), wxPoint(93,24), wxSize(336,21), arrayStringFor_WxComboBox1, wxCB_DROPDOWN | wxCB_READONLY | wxCB_SORT, wxDefaultValidator, wxT("WxComboBox1"));
 
-	WxEdit1 = new wxTextCtrl(this, ID_WXEDIT1, wxT("WxEdit1"), wxPoint(93,49), wxSize(216,21), 0, wxDefaultValidator, wxT("WxEdit1"));
+	WxEdit1 = new wxTextCtrl(this, ID_WXEDIT1, wxT("WxEdit1"), wxPoint(93,50), wxSize(335,21), 0, wxDefaultValidator, wxT("WxEdit1"));
 
 	wxArrayString arrayStringFor_WxComboBox2;
-	WxComboBox2 = new wxComboBox(this, ID_WXCOMBOBOX2, wxT("WxComboBox2"), wxPoint(92,76), wxSize(218,21), arrayStringFor_WxComboBox2, wxCB_DROPDOWN | wxCB_READONLY | wxCB_SORT, wxDefaultValidator, wxT("WxComboBox2"));
+	WxComboBox2 = new wxComboBox(this, ID_WXCOMBOBOX2, wxT("WxComboBox2"), wxPoint(93,76), wxSize(335,21), arrayStringFor_WxComboBox2, wxCB_DROPDOWN | wxCB_READONLY | wxCB_SORT, wxDefaultValidator, wxT("WxComboBox2"));
 
 	WxCheckBox1 = new wxCheckBox(this, ID_WXCHECKBOX1, wxT("set phone clock from your computer"), wxPoint(14,103), wxSize(296,18), 0, wxDefaultValidator, wxT("WxCheckBox1"));
-	WxCheckBox1->Show(false);
 
-	WxButton2 = new wxButton(this, ID_WXBUTTON2, wxT("&OK"), wxPoint(40,151), wxSize(82,23), 0, wxDefaultValidator, wxT("WxButton2"));
+	WxButton2 = new wxButton(this, ID_WXBUTTON2, wxT("&OK"), wxPoint(40,170), wxSize(82,23), 0, wxDefaultValidator, wxT("WxButton2"));
 
-	WxButton3 = new wxButton(this, ID_WXBUTTON3, wxT("&Cancel"), wxPoint(280,152), wxSize(81,23), 0, wxDefaultValidator, wxT("WxButton3"));
+	WxButton3 = new wxButton(this, ID_WXBUTTON3, wxT("&Cancel"), wxPoint(312,171), wxSize(81,23), 0, wxDefaultValidator, wxT("WxButton3"));
 
 	WxStaticText3 = new wxStaticText(this, ID_WXSTATICTEXT3, wxT("Phone model"), wxPoint(14,78), wxDefaultSize, 0, wxT("WxStaticText3"));
 
 	WxStaticText2 = new wxStaticText(this, ID_WXSTATICTEXT2, wxT("Device"), wxPoint(14,52), wxDefaultSize, 0, wxT("WxStaticText2"));
 
-	WxStaticText1 = new wxStaticText(this, ID_WXSTATICTEXT1, wxT("Type"), wxPoint(15,23), wxDefaultSize, 0, wxT("WxStaticText1"));
+	WxStaticText1 = new wxStaticText(this, ID_WXSTATICTEXT1, wxT("Type"), wxPoint(15,25), wxDefaultSize, 0, wxT("WxStaticText1"));
 
-	WxStaticBox1 = new wxStaticBox(this, ID_WXSTATICBOX1, wxT("Parameters"), wxPoint(3,6), wxSize(395,139));
+	WxStaticBox1 = new wxStaticBox(this, ID_WXSTATICBOX1, wxT("Parameters"), wxPoint(3,6), wxSize(432,160));
 	////GUI Items Creation End
 }
 
@@ -102,7 +103,8 @@ void CfgDlg::SetConfig(GSM_GPlusConfig *CFG2, GSM_StateMachine *s2)
     
     if (strcmp(CFG->LogLevel,"nothing")) WxCheckBox2->SetValue(true);
     if (!strcmp(CFG->SyncTime,"yes")) WxCheckBox1->SetValue(true);
-        
+    if (!strcmp(CFG->GetOnlineInfo,"yes")) WxCheckBox3->SetValue(true);
+            
     //device
     WxEdit1->SetValue(StringToUnicodeReturn(CFG->Device));
     
@@ -130,15 +132,17 @@ void CfgDlg::SetConfig(GSM_GPlusConfig *CFG2, GSM_StateMachine *s2)
 typedef struct {
  	char		*Connection;
 	char		*Description;
+	char        *Device;
 } X;
 
     X   X2[] = {
-    	"bluerfphonet", "Nokia - bluetooth (Microsoft stack) for old models",
-    	"bluephonet", "Nokia - bluetooth (Microsoft stack) for new models",
-    	"irdaphonet", "Nokia - infrared",
-    	"dku2", "Nokia - DKU2 USB cable for PopPort",
-    	"fbus", "Nokia - FBUS cable",
-    	"",""};
+    	"bluerfphonet", "Nokia - bluetooth for old models (with Microsoft stack)", "Phone address",
+    	"bluephonet", "Nokia - bluetooth for new models (with Microsoft stack)", "Phone address",
+    	"phonetblue", "Nokia - bluetooth over 'Nokia PC Suite' service (with any stack)", "Serial port",
+    	"irdaphonet", "Nokia - infrared", "Device",
+    	"dku2", "Nokia - DKU2 USB cable for PopPort (with Nokia driver)", "Device",
+    	"fbus", "Nokia - FBUS cable","Serial port",
+    	"","",""};
 
 void CfgDlg::SelectChoice1()
 {
@@ -163,6 +167,7 @@ void CfgDlg::SelectChoice1()
                     sprintf(CFG->Protocol,"%s",X2[i].Connection);
                     WxEdit1->Enable((*proinfo).NeedPort);
                     WxStaticText2->Enable((*proinfo).NeedPort);
+                    WxStaticText2->SetLabel(X2[i].Device);
                 }
             }
         }
@@ -258,14 +263,12 @@ void CfgDlg::WxButton2Click(wxCommandEvent& event)
     } else {
         sprintf(CFG->LogLevel,"nothing");
     }
+    if (WxCheckBox3->GetValue()) {
+        sprintf(CFG->GetOnlineInfo,"yes");
+    } else {
+        sprintf(CFG->GetOnlineInfo,"no");
+    }
     
-//    wxMessageBox(Connection,"connection",
-//           wxICON_WARNING | wxOK);
-//    wxMessageBox(Device,"device",
-//           wxICON_WARNING | wxOK);
-//    wxMessageBox(Model,"model",
-//           wxICON_WARNING | wxOK);
-                               
     EndModal(wxID_OK);
 }
 
