@@ -58,6 +58,7 @@ class CfgDlg : public wxDialog
                 //GUI Control Declaration Start and GUI Control Declaration End.
 		//wxDev-C++ will remove them. Add custom code after the block.
 		////GUI Control Declaration Start
+		wxCheckBox *WxCheckBox3;
 		wxCheckBox *WxCheckBox2;
 		wxComboBox *WxComboBox1;
 		wxTextCtrl *WxEdit1;
@@ -79,6 +80,7 @@ class CfgDlg : public wxDialog
 		enum
 		{
 			////GUI Enum Control ID Start
+			ID_WXCHECKBOX3 = 1017,
 			ID_WXCHECKBOX2 = 1016,
 			ID_WXCOMBOBOX1 = 1013,
 			ID_WXEDIT1 = 1003,
