@@ -66,7 +66,7 @@ void PrintDT(GSM_DateTime *DT, char *Buffer)
             DT->Hour,
             DT->Minute,
             DT->Second);
-    } else {    
+    } else if (Days>0) {    
         sprintf(Buffer, "%s %02i-%02i-%04i %02i:%02i:%02i (%i days ago)",
             DayOfWeekStr(
                     DT->Year,
@@ -79,6 +79,18 @@ void PrintDT(GSM_DateTime *DT, char *Buffer)
             DT->Minute,
             DT->Second,
             Days);
+    } else {
+        sprintf(Buffer, "%s %02i-%02i-%04i %02i:%02i:%02i",
+            DayOfWeekStr(
+                    DT->Year,
+                    DT->Month,
+                    DT->Day),
+            DT->Day,
+            DT->Month,
+            DT->Year,
+            DT->Hour,
+            DT->Minute,
+            DT->Second);
     }
 }
 
